/* attribute 'centroid' - centroid of current state */
/* $Id: at_centroid.h,v 1.1 1993/05/26 23:22:27 coleman Exp $ */

#ifndef at_centroid_h
# define at_centroid_h 1

# include "aglo.h"

aglo_const_point at_centroid(aglo_state state); 

#endif /* at_centroid_h */
