/* generally useful macros and inlines */
/* $Id: defines.h,v 1.1 1993/05/26 23:22:27 coleman Exp $ */

#ifndef defines_h
# define defines_h

#define sqr(d) ((d)*(d))

#define fmax(d1, d2) (((d1) < (d2)) ? (d2) : (d1))

#endif /* defines_h */
